==> haskell-rsa-2.4.1-330.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 RSA
version:              2.4.1
visibility:           public
id:                   RSA-2.4.1-JmsPyfqrInc4jyXQicqwhl
key:                  RSA-2.4.1-JmsPyfqrInc4jyXQicqwhl
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@galois.com>
author:               Adam Wick <awick@galois.com>
stability:            stable
synopsis:
    Implementation of RSA, using the padding schemes of PKCS#1 v2.1.

description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).

category:             Cryptography, Codec
abi:                  951c9bc6eedb88c08b7427974a1984a5
exposed:              True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure

import-dirs:          /usr/lib/ghc-9.6.6/site-local/RSA-2.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/RSA-2.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/RSA-2.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rsa
hs-libraries:         HSRSA-2.4.1-JmsPyfqrInc4jyXQicqwhl
depends:
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 crypto-api-0.13.3-7R6mWxyWT8b203JTOR7lix
    crypto-pubkey-types-0.4.3-FJtMwIK4cJXEyUUz4Hc1UZ

haddock-interfaces:   /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html:         /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rsa-2.4.1-331-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 RSA
version:              2.4.1
visibility:           public
id:                   RSA-2.4.1-B3TIboGPJHEGFjYqmtreE8
key:                  RSA-2.4.1-B3TIboGPJHEGFjYqmtreE8
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@galois.com>
author:               Adam Wick <awick@galois.com>
stability:            stable
synopsis:
    Implementation of RSA, using the padding schemes of PKCS#1 v2.1.

description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).

category:             Cryptography, Codec
abi:                  ccf04aec9202942babe88edbbff0950b
exposed:              True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure

import-dirs:          /usr/lib/ghc-9.6.6/site-local/RSA-2.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/RSA-2.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/RSA-2.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rsa
hs-libraries:         HSRSA-2.4.1-B3TIboGPJHEGFjYqmtreE8
depends:
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 crypto-api-0.13.3-7R6mWxyWT8b203JTOR7lix
    crypto-pubkey-types-0.4.3-LtvOSYtrBsuKcyGAqwMgm8

haddock-interfaces:   /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html:         /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
